from setuptools import setup, find_packages

setup(
    name='vlpaket',
    version='0.1.0',
    author='vadlap',
    author_email='vadlaped@gmail.com',
    description='Best package',
    long_description=open('README.md').read(),
    packages=find_packages()
)